bwaaa

4 modules for users:

1. User Config
    - Whenever you run code that requires a dataset, RedPlanet will (1) check if the file is in your local cache and has the correct hash, and if not then (2) download the file.
    - You can specify various options like where the data is stored, how file integrity is checked, etc.
2. Datasets
    - Loading and accessing various datasets
3. Analysis
    - Various analysis tools
4. Helper Functions
    - Miscellaneous convenience functions

